==> fusing-angular-0.0.11.tgz: package/index.ts <==
import { FuseBox, QuantumPlugin, EnvPlugin } from "fuse-box"
import { argv } from 'yargs'
import { NgCompilerPlugin } from "./tools/plugins/ng.compiler.plugin"
import { NgPolyfillPlugin } from "./tools/plugins/ng.polyfill.plugin"
import { NgProdPlugin } from "./tools/plugins/ng.prod.plugin"
import { NgOptimizerPlugin } from "./tools/plugins/ng.optimizer.plugin"
import { NgServerModulePlugin } from "./tools/plugins/ng.server.module.plugin"
import { NgBootstrapPlugin } from "./tools/plugins/ng.bootstrap.plugin"
import { lstat, copyFile, mkdir } from "fs/promises"
import { resolve } from "path"

export interface FusingAngularConfig {
  productionBuild?: boolean
  supportIE11?: boolean
  supportIE11Animations?: boolean
  enableAotCompilaton?: boolean
  enableAngularAnimations?: boolean
  enableAngularForms?: boolean
  enableServiceWorker?: boolean
  enableAngularBuildOptimizer?: boolean
  serverPort?: number

  angularServerModule?: {
    moduleName: string
    modulePath: string
  }
  angularBrowserModulePath?: string
  expressServerPath?: string
}

const DEFAULT_CONFIG: FusingAngularConfig = {
  enableAotCompilaton: argv.aot,
  productionBuild: argv.prod,
  supportIE11: true,
  supportIE11Animations: false,
  enableAngularAnimations: false,
  enableAngularForms: false,
  enableServiceWorker: false,
  serverPort: process.env.PORT && +process.env.PORT || 5000,
  angularServerModule: {
    moduleName: 'AppServerModule',
    modulePath: 'src/server/server.angular.module'
  }
}

enum NG_CONTAINER {
  SERVER = 'src/server',
  BROWSER = 'src/browser'
}

const resolveNgFile = (container: NG_CONTAINER, file: string) => {
  const originPath = resolve(`node_modules/${container}`)
  const serverPath = resolve(container)
  const filePath = resolve(serverPath, file)

  return lstat(filePath)
    .catch(() => copyFile(resolve(originPath, file), filePath)
      .catch(() => {
        throw new Error('failed to load file')
      }))
}

const makeBaseDir = () => {
  return Promise.all([
    mkdir(resolve('src/server')).catch((() => undefined)),
    mkdir(resolve('src/browser')).catch((() => undefined))
  ])
}

const init = () => {
  makeBaseDir().then(() => {
    resolveNgFile(NG_CONTAINER.SERVER, 'server.ts')
  })
  
  // const basePath = resolve('src')
  // const originPath = resolve('node_modules/src/server')
  // const serverPath = resolve('src/server')
  // const filePath = resolve(serverPath, 'server.ts')
  // lstat('filePath')

  //   .catch(() => {
  //     return copyFile('node_modules/src/server/server.ts', filePath).catch(console.log)
  //   })
  //   .then(console.log)
}

export function fusingAngular(opts?: FusingAngularConfig) {
  init()
  const settings = {
    ...DEFAULT_CONFIG,
    ...opts
  }
  const fuseBrowser = FuseBox.init({
    homeDir: "./",
    output: "./.dist/public/js/$name.js",
    target: 'browser@es5',
    cache: !settings.productionBuild,
    plugins: [
      NgBootstrapPlugin({ enabled: settings.enableAotCompilaton }),
      NgProdPlugin({ enabled: settings.productionBuild }),
      NgPolyfillPlugin(),
      NgCompilerPlugin({ enabled: settings.enableAotCompilaton }),
      NgOptimizerPlugin({ enabled: settings.enableAngularBuildOptimizer }),
      settings.productionBuild && QuantumPlugin({
        bakeApiIntoBundle: 'vendor',
        warnings: false,
        uglify: true,
        treeshake: true,
        ensureES5: true
      })
    ] as any
  })

  const fuseServer = FuseBox.init({
    target: 'server@es5',
    homeDir: "./",
    output: "./.dist/$name.js",
    cache: !settings.productionBuild,
    plugins: [
      EnvPlugin({ serverPort: settings.serverPort }),
      NgProdPlugin({ enabled: settings.productionBuild, fileTest: 'server.angular.module' }),
      settings.angularServerModule && NgServerModulePlugin({
        module: settings.angularServerModule.moduleName,
        path: settings.angularServerModule.modulePath
      }),
      NgPolyfillPlugin({ isServer: true, fileTest: 'server.angular.module' })
    ] as any[]
  })

  const vendorBundle = fuseBrowser.bundle('vendor')
  const appBundle = fuseBrowser.bundle('app')
  const serverBundle = fuseServer.bundle("server")

  const browserBundlePath = settings.angularBrowserModulePath
    ? settings.angularBrowserModulePath
    : 'src/browser/app.browser.module.ts'

  const serverBundlePath = settings.expressServerPath
    ? settings.expressServerPath
    : '@node_modules/fusing-angular/src/server/server.ts'

  vendorBundle.instructions(` ~ ${browserBundlePath}`)
  appBundle.instructions(` !> [${browserBundlePath}]`)
  serverBundle
    .instructions(` > [${serverBundlePath}]`)
    .completed(proc => proc.start())

  if (!settings.productionBuild) {
    appBundle.watch('src/**')
    serverBundle.watch("src/**")
    fuseServer.dev({
      root: './.dist',
      port: settings.serverPort,
      httpServer: false
    })
  }

  fuseBrowser.run()
  fuseServer.run()
}

==> fusing-angular-0.0.12.tgz: package/index.ts <==
import { FuseBox, QuantumPlugin, EnvPlugin } from "fuse-box"
import { argv } from 'yargs'
import { NgCompilerPlugin } from "./tools/plugins/ng.compiler.plugin"
import { NgPolyfillPlugin } from "./tools/plugins/ng.polyfill.plugin"
import { NgProdPlugin } from "./tools/plugins/ng.prod.plugin"
import { NgOptimizerPlugin } from "./tools/plugins/ng.optimizer.plugin"
import { NgServerModulePlugin } from "./tools/plugins/ng.server.module.plugin"
import { NgBootstrapPlugin } from "./tools/plugins/ng.bootstrap.plugin"
import { mkdir, readdir, lstat, copyFile } from "fs/promises"
import { resolve } from "path"

export interface FusingAngularConfig {
  productionBuild?: boolean
  supportIE11?: boolean
  supportIE11Animations?: boolean
  enableAotCompilaton?: boolean
  enableAngularAnimations?: boolean
  enableAngularForms?: boolean
  enableServiceWorker?: boolean
  enableAngularBuildOptimizer?: boolean
  serverPort?: number

  angularServerModule?: {
    moduleName: string
    modulePath: string
  }
  angularBrowserModulePath?: string
  expressServerPath?: string
}

const DEFAULT_CONFIG: FusingAngularConfig = {
  enableAotCompilaton: argv.aot,
  productionBuild: argv.prod,
  supportIE11: true,
  supportIE11Animations: false,
  enableAngularAnimations: false,
  enableAngularForms: false,
  enableServiceWorker: false,
  serverPort: process.env.PORT && +process.env.PORT || 5000,
  angularServerModule: {
    moduleName: 'AppServerModule',
    modulePath: 'src/server/server.angular.module'
  }
}

// enum NG_CONTAINER {
//   SERVER = 'src/server',
//   BROWSER = 'src/browser'
// }

// const resolveNgFile = (container: NG_CONTAINER, file: string) => {
//   const originPath = resolve(`node_modules/${container}`)
//   const serverPath = resolve(container)
//   const filePath = resolve(serverPath, file)

//   return lstat(filePath)
//     .catch(() => copyFile(resolve(originPath, file), filePath)
//       .catch(() => {
//         throw new Error('failed to load file')
//       }))
// }

const makeBaseDir = () => {
  return Promise.all([
    mkdir(resolve('src/server')).catch((() => undefined)),
    mkdir(resolve('src/browser')).catch((() => undefined))
  ])
}

const copyDir = (basePath: string) => {
  readdir(basePath)
    .then(filePaths => filePaths.map(filePath => {
      return lstat(resolve(basePath, filePath))
        .catch(() => {
          return copyFile(resolve(`node_modules/fusing-angular/${basePath}`, filePath),
            resolve(basePath, filePath))
        })
    }))
}

const init = () => {
  makeBaseDir()
    .then(() => {
      return Promise.all([
        copyDir('src/server'),
        copyDir('src/browser')
      ])
    })

  // const basePath = resolve('src')
  // const originPath = resolve('node_modules/src/server')
  // const serverPath = resolve('src/server')
  // const filePath = resolve(serverPath, 'server.ts')
  // lstat('filePath')

  //   .catch(() => {
  //     return copyFile('node_modules/src/server/server.ts', filePath).catch(console.log)
  //   })
  //   .then(console.log)
}

export function fusingAngular(opts?: FusingAngularConfig) {
  init()
  const settings = {
    ...DEFAULT_CONFIG,
    ...opts
  }
  const fuseBrowser = FuseBox.init({
    homeDir: "./",
    output: "./.dist/public/js/$name.js",
    target: 'browser@es5',
    cache: !settings.productionBuild,
    plugins: [
      NgBootstrapPlugin({ enabled: settings.enableAotCompilaton }),
      NgProdPlugin({ enabled: settings.productionBuild }),
      NgPolyfillPlugin(),
      NgCompilerPlugin({ enabled: settings.enableAotCompilaton }),
      NgOptimizerPlugin({ enabled: settings.enableAngularBuildOptimizer }),
      settings.productionBuild && QuantumPlugin({
        bakeApiIntoBundle: 'vendor',
        warnings: false,
        uglify: true,
        treeshake: true,
        ensureES5: true
      })
    ] as any
  })

  const fuseServer = FuseBox.init({
    target: 'server@es5',
    homeDir: "./",
    output: "./.dist/$name.js",
    cache: !settings.productionBuild,
    plugins: [
      EnvPlugin({ serverPort: settings.serverPort }),
      NgProdPlugin({ enabled: settings.productionBuild, fileTest: 'server.angular.module' }),
      settings.angularServerModule && NgServerModulePlugin({
        module: settings.angularServerModule.moduleName,
        path: settings.angularServerModule.modulePath
      }),
      NgPolyfillPlugin({ isServer: true, fileTest: 'server.angular.module' })
    ] as any[]
  })

  const vendorBundle = fuseBrowser.bundle('vendor')
  const appBundle = fuseBrowser.bundle('app')
  const serverBundle = fuseServer.bundle("server")

  const browserBundlePath = settings.angularBrowserModulePath
    ? settings.angularBrowserModulePath
    : 'src/browser/app.browser.module.ts'

  const serverBundlePath = settings.expressServerPath
    ? settings.expressServerPath
    : 'src/server/server.ts'

  vendorBundle.instructions(` ~ ${browserBundlePath}`)
  appBundle.instructions(` !> [${browserBundlePath}]`)
  serverBundle
    .instructions(` > [${serverBundlePath}]`)
    .completed(proc => proc.start())

  if (!settings.productionBuild) {
    appBundle.watch('src/**')
    serverBundle.watch("src/**")
    fuseServer.dev({
      root: './.dist',
      port: settings.serverPort,
      httpServer: false
    })
  }

  fuseBrowser.run()
  fuseServer.run()
}
